# LMK Python Client - Jupyter Widget

This is the README for the `@lmkapp/jupyter-widget` npm package. This package contains the source code for the Jupyter widget that you can use to monitor your Jupyter notebooks with LMK. This package is not intended to be installed directly; it should normally be fetched by some other program that provides a context to embed the widget in e.g. VSCode.

You can find the README for the `lmk` repository [here](https://github.com/lmkapp/lmk).
